pub enum ToolCallAction {
Run,
Rewrite(Value),
Skip(String),
Stop(String),
}Available on crate feature
agent only.Expand description
Action for pre-tool hooks.
Variants
Run
Execute with the current arguments.
Rewrite(Value)
Execute with replacement arguments.
Skip(String)
Do not execute; return this feedback to the model.
Stop(String)
Stop the run.
Implementations
Sourceimpl ToolCallAction
impl ToolCallAction
Sourcepub fn run() -> ToolCallAction
pub fn run() -> ToolCallAction
Creates an action that executes the tool with the current arguments.
Sourcepub fn rewrite(args: impl Into<Value>) -> ToolCallAction
pub fn rewrite(args: impl Into<Value>) -> ToolCallAction
Creates an action that replaces the arguments passed to the tool.
Sourcepub fn try_rewrite<T>(args: &T) -> Result<ToolCallAction, Error>where
T: Serialize,
pub fn try_rewrite<T>(args: &T) -> Result<ToolCallAction, Error>where
T: Serialize,
Serializes replacement arguments and creates a rewrite action.
Returns an error when args cannot be represented as JSON.
Sourcepub fn skip(reason: impl Into<String>) -> ToolCallAction
pub fn skip(reason: impl Into<String>) -> ToolCallAction
Creates an action that skips execution and returns feedback to the model.
Sourcepub fn stop(reason: impl Into<String>) -> ToolCallAction
pub fn stop(reason: impl Into<String>) -> ToolCallAction
Creates an action that stops the run before executing the tool.