#[non_exhaustive]pub struct CompletionCall {
pub call_index: usize,
pub usage: Usage,
}Expand description
Details for one successfully completed completion request made by an agent run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.call_index: usizeZero-based index of the completion request within this agent run.
usage: UsageToken usage reported for this completion request.
Zero-valued usage is Usage’s documented sentinel for missing
provider usage metrics; rig does not distinguish “reported all zeros”
from “unreported”.
Implementations
Sourceimpl CompletionCall
impl CompletionCall
Sourcepub fn new(call_index: usize, usage: Usage) -> CompletionCall
pub fn new(call_index: usize, usage: Usage) -> CompletionCall
Create details for one completion request in an agent run.