ProviderClientError

Enum ProviderClientError 

#[non_exhaustive]
pub enum ProviderClientError { EnvironmentVariable { name: &'static str, source: VarError, }, Http(Error), InvalidConfiguration(&'static str), }
Errors returned while constructing provider clients from environment variables or explicit input.

Provider-specific client constructors use this error for configuration problems that can be detected before any model request is sent, such as missing API keys, invalid environment values, or invalid builder configuration.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EnvironmentVariable

A required or optional environment variable could not be read as valid Unicode.

For required variables, this variant is also returned when the variable is not present.

Fields

name: &'static str

The environment variable name.

source: VarError

The underlying environment lookup error.



Http(Error)

The underlying provider client builder failed while constructing HTTP configuration.



InvalidConfiguration(&'static str)

The provider received an unsupported or incomplete configuration.