pub enum Message {
System {
content: String,
},
User {
content: OneOrMany<UserContent>,
},
Assistant {
id: Option<String>,
content: OneOrMany<AssistantContent>,
},
}Expand description
A provider-agnostic chat message.
Messages are role-tagged and may contain one or many content items, including text, images, audio, documents, tool calls, and tool results. Provider modules are responsible for translating these generic messages into provider-native request bodies. That conversion may be lossy when a provider does not support a particular content type.
Variants
System
System message containing instruction text.
User
User message containing one or more content types defined by UserContent.
Fields
content: OneOrMany<UserContent>Assistant
Assistant message containing one or more content types defined by AssistantContent.
Implementations
Sourceimpl Message
impl Message
Sourcepub fn system(text: impl Into<String>) -> Message
pub fn system(text: impl Into<String>) -> Message
Helper constructor to make creating system messages easier.
Sourcepub fn user(text: impl Into<String>) -> Message
pub fn user(text: impl Into<String>) -> Message
Helper constructor to make creating user messages easier.
Sourcepub fn assistant(text: impl Into<String>) -> Message
pub fn assistant(text: impl Into<String>) -> Message
Helper constructor to make creating assistant messages easier.
Sourcepub fn assistant_with_id(id: String, text: impl Into<String>) -> Message
pub fn assistant_with_id(id: String, text: impl Into<String>) -> Message
Helper constructor to make creating assistant messages easier.
Sourcepub fn tool_result(id: impl Into<String>, content: impl Into<String>) -> Message
pub fn tool_result(id: impl Into<String>, content: impl Into<String>) -> Message
Helper constructor to make creating tool result messages easier.
pub fn tool_result_with_call_id( id: impl Into<String>, call_id: Option<String>, content: impl Into<String>, ) -> Message