pub struct ToolSchema {
pub name: String,
pub context: Value,
pub embedding_docs: Vec<String>,
}Expand description
Embeddable document that is used as an intermediate representation of a tool when RAGging tools.
Fields
name: Stringcontext: Valueembedding_docs: Vec<String>Implementations
Sourceimpl ToolSchema
impl ToolSchema
Sourcepub fn try_from<T>(tool: &T) -> Result<ToolSchema, EmbedError>where
T: PortableToolEmbedding + 'static,
pub fn try_from<T>(tool: &T) -> Result<ToolSchema, EmbedError>where
T: PortableToolEmbedding + 'static,
Convert an embedding-backed tool to a ToolSchema.
Example
use rig_core::{
embeddings::ToolSchema,
tool::{PortableTool, PortableToolEmbedding},
};
#[derive(Debug, thiserror::Error)]
#[error("Nothing error")]
struct NothingError;
#[derive(Debug, thiserror::Error)]
#[error("Init error")]
struct InitError;
struct Nothing;
impl PortableTool for Nothing {
const NAME: &'static str = "nothing";
type Args = ();
type Output = ();
type Error = NothingError;
fn description(&self) -> String {
"nothing".to_string()
}
fn parameters(&self) -> serde_json::Value {
serde_json::json!({})
}
async fn call(&self, _args: Self::Args) -> Result<Self::Output, Self::Error> {
Ok(())
}
}
impl PortableToolEmbedding for Nothing {
type InitError = InitError;
type Context = ();
type State = ();
fn init(_state: Self::State, _context: Self::Context) -> Result<Self, Self::InitError> {
Ok(Nothing)
}
fn embedding_docs(&self) -> Vec<String> {
vec!["Do nothing.".into()]
}
fn context(&self) -> Self::Context {}
}
let tool = ToolSchema::try_from(&Nothing).unwrap();
assert_eq!(tool.name, "nothing".to_string());
assert_eq!(tool.embedding_docs, vec!["Do nothing.".to_string()]);Trait Implementations
Sourceimpl Clone for ToolSchema
impl Clone for ToolSchema
Sourcefn clone(&self) -> ToolSchema
fn clone(&self) -> ToolSchema
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for ToolSchema
impl Default for ToolSchema
Sourcefn default() -> ToolSchema
fn default() -> ToolSchema
Returns the “default value” for a type. Read more
Sourceimpl Embed for ToolSchema
impl Embed for ToolSchema
Sourcefn embed(&self, embedder: &mut TextEmbedder) -> Result<(), EmbedError>
fn embed(&self, embedder: &mut TextEmbedder) -> Result<(), EmbedError>
Append all text fragments that should be embedded for this value.
impl Eq for ToolSchema
Sourceimpl PartialEq for ToolSchema
impl PartialEq for ToolSchema
Sourceimpl Serialize for ToolSchema
impl Serialize for ToolSchema
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ToolSchema