pub struct CohereBuilder;Trait Implementations
Sourceimpl Clone for CohereBuilder
impl Clone for CohereBuilder
Sourcefn clone(&self) -> CohereBuilder
fn clone(&self) -> CohereBuilder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for CohereBuilder
Sourceimpl Debug for CohereBuilder
impl Debug for CohereBuilder
Sourceimpl Default for CohereBuilder
impl Default for CohereBuilder
Sourcefn default() -> CohereBuilder
fn default() -> CohereBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for CohereBuilder
impl ProviderBuilder for CohereBuilder
Sourcetype Extension<H: HttpClientExt> = CohereExt
type Extension<H: HttpClientExt> = CohereExt
Provider extension type built for a concrete HTTP backend.
Sourcetype ApiKey = BearerAuth
type ApiKey = BearerAuth
API key input type accepted by the provider’s client builder.
Sourcefn build<H>(
_builder: &ClientBuilder<CohereBuilder, <CohereBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<CohereBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<CohereBuilder, <CohereBuilder as ProviderBuilder>::ApiKey, H>,
) -> Result<<CohereBuilder as ProviderBuilder>::Extension<H>, Error>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>, Error>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersAuto Trait Implementations
impl Freeze for CohereBuilder
impl RefUnwindSafe for CohereBuilder
impl Send for CohereBuilder
impl Sync for CohereBuilder
impl Unpin for CohereBuilder
impl UnsafeUnpin for CohereBuilder
impl UnwindSafe for CohereBuilder