pub enum DataCollection {
Allow,
Deny,
}Expand description
Data collection policy for providers.
Controls whether providers are allowed to collect and store request data.
Variants
Allow
Allow providers that may collect data (default)
Deny
Restrict routing to providers that do not store user data non-transiently