ExtractorBuilder

Struct ExtractorBuilder 

pub struct ExtractorBuilder<M, T>
where M: CompletionModel, T: JsonSchema + for<'a> Deserialize<'a> + Serialize + WasmCompatSend + WasmCompatSync + 'static,
{ /* private fields */ }
Builder for the Extractor

Implementations

Source

impl<M, T> ExtractorBuilder<M, T>
where M: CompletionModel, T: JsonSchema + for<'a> Deserialize<'a> + Serialize + WasmCompatSend + WasmCompatSync + 'static,

pub fn new(model: M) -> Self

pub fn preamble(self, preamble: &str) -> Self

Add additional preamble to the extractor

pub fn context(self, doc: &str) -> Self

Add a context document to the extractor

pub fn additional_params(self, params: Value) -> Self

pub fn max_tokens(self, max_tokens: u64) -> Self

Set the maximum number of tokens for the completion

pub fn retries(self, retries: u64) -> Self

Set the maximum number of retries for the extractor.

pub fn tool_choice(self, choice: ToolChoice) -> Self

Set the tool_choice option for the inner Agent.

pub fn build(self) -> Extractor<M, T>

Build the Extractor

pub fn dynamic_context( self, sample: usize, dynamic_context: impl VectorStoreIndexDyn + Send + Sync + 'static, ) -> Self

Add dynamic context (RAG) to the extractor.

On each prompt, sample documents will be retrieved from the index based on the RAG text and inserted in the request.