pub struct GenerateContentRequest {
pub model: String,
pub contents: Vec<Content>,
pub safety_settings: Vec<SafetySetting>,
pub generation_config: Option<GenerationConfig>,
pub tools: Vec<Tool>,
pub tool_config: Option<ToolConfig>,
pub system_instruction: Option<Content>,
pub cached_content: String,
}Available on crate feature
gemini-grpc only.Fields
model: Stringcontents: Vec<Content>safety_settings: Vec<SafetySetting>generation_config: Option<GenerationConfig>tools: Vec<Tool>tool_config: Option<ToolConfig>system_instruction: Option<Content>cached_content: StringTrait Implementations
Sourceimpl Clone for GenerateContentRequest
impl Clone for GenerateContentRequest
Sourcefn clone(&self) -> GenerateContentRequest
fn clone(&self) -> GenerateContentRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GenerateContentRequest
impl Debug for GenerateContentRequest
Sourceimpl Default for GenerateContentRequest
impl Default for GenerateContentRequest
Sourcefn default() -> GenerateContentRequest
fn default() -> GenerateContentRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GenerateContentRequest
impl<'de> Deserialize<'de> for GenerateContentRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GenerateContentRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GenerateContentRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Message for GenerateContentRequest
impl Message for GenerateContentRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for GenerateContentRequest
impl PartialEq for GenerateContentRequest
Sourceimpl Serialize for GenerateContentRequest
impl Serialize for GenerateContentRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for GenerateContentRequest