pub struct CopilotBuilder { /* private fields */ }Trait Implementations
Sourceimpl Clone for CopilotBuilder
impl Clone for CopilotBuilder
Sourcefn clone(&self) -> CopilotBuilder
fn clone(&self) -> CopilotBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CopilotBuilder
impl Debug for CopilotBuilder
Sourceimpl Default for CopilotBuilder
impl Default for CopilotBuilder
Sourceimpl ProviderBuilder for CopilotBuilder
impl ProviderBuilder for CopilotBuilder
const BASE_URL: &'static str = GITHUB_COPILOT_API_BASE_URL
type Extension<H> = CopilotExt where H: HttpClientExt
type ApiKey = CopilotAuth
Sourcefn build<H>(
builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
fn build<H>(
builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersAuto Trait Implementations
impl Freeze for CopilotBuilder
impl !RefUnwindSafe for CopilotBuilder
impl Send for CopilotBuilder
impl Sync for CopilotBuilder
impl Unpin for CopilotBuilder
impl UnsafeUnpin for CopilotBuilder
impl !UnwindSafe for CopilotBuilder