pub struct InteractionsCompletionModel<T = Client> {
pub model: String,
/* private fields */
}Expand description
Completion model wrapper for the Gemini Interactions API.
Fields
model: StringImplementations
Sourceimpl<T> InteractionsCompletionModel<T>
impl<T> InteractionsCompletionModel<T>
Sourcepub fn new(client: InteractionsClient<T>, model: impl Into<String>) -> Self
pub fn new(client: InteractionsClient<T>, model: impl Into<String>) -> Self
Create a new Interactions completion model for the given client and model name.
Sourcepub fn with_model(client: InteractionsClient<T>, model: &str) -> Self
pub fn with_model(client: InteractionsClient<T>, model: &str) -> Self
Create a new Interactions completion model using a string model name.
Sourcepub fn generate_content_api(self) -> CompletionModel<T>
pub fn generate_content_api(self) -> CompletionModel<T>
Use the GenerateContent API instead of Interactions.
Sourceimpl<T> InteractionsCompletionModel<T>
impl<T> InteractionsCompletionModel<T>
Sourcepub async fn create_interaction(
&self,
completion_request: CompletionRequest,
) -> Result<Interaction, CompletionError>
pub async fn create_interaction( &self, completion_request: CompletionRequest, ) -> Result<Interaction, CompletionError>
Create an interaction and return the raw response payload.
Sourcepub async fn get_interaction(
&self,
interaction_id: impl AsRef<str>,
) -> Result<Interaction, CompletionError>
pub async fn get_interaction( &self, interaction_id: impl AsRef<str>, ) -> Result<Interaction, CompletionError>
Fetch an interaction by ID for polling background tasks.
Sourcepub async fn stream_interaction_events(
&self,
completion_request: CompletionRequest,
) -> Result<InteractionEventStream, CompletionError>
pub async fn stream_interaction_events( &self, completion_request: CompletionRequest, ) -> Result<InteractionEventStream, CompletionError>
Start an interaction and stream raw SSE events.
Sourcepub async fn stream_interaction_events_by_id(
&self,
interaction_id: impl AsRef<str>,
last_event_id: Option<&str>,
) -> Result<InteractionEventStream, CompletionError>
pub async fn stream_interaction_events_by_id( &self, interaction_id: impl AsRef<str>, last_event_id: Option<&str>, ) -> Result<InteractionEventStream, CompletionError>
Resume an interaction stream by ID and optional last event ID.