pub struct Client { /* private fields */ }Implementations
Sourceimpl Client
impl Client
Sourcepub fn from_url(api_key: &str, base_url: &str) -> Self
pub fn from_url(api_key: &str, base_url: &str) -> Self
Create a new Groq client with the given API key and base API URL.
Sourcepub fn from_env() -> Self
pub fn from_env() -> Self
Create a new Groq client from the GROQ_API_KEY environment variable.
Panics if the environment variable is not set.
Sourcepub fn completion_model(&self, model: &str) -> CompletionModel
pub fn completion_model(&self, model: &str) -> CompletionModel
Create a completion model with the given name.
Example
use rig::providers::groq::{Client, self};
// Initialize the Groq client
let groq = Client::new("your-groq-api-key");
let gpt4 = groq.completion_model(groq::GPT_4);Sourcepub fn agent(&self, model: &str) -> AgentBuilder<CompletionModel>
pub fn agent(&self, model: &str) -> AgentBuilder<CompletionModel>
Create an agent builder with the given completion model.
Example
use rig::providers::groq::{Client, self};
// Initialize the Groq client
let groq = Client::new("your-groq-api-key");
let agent = groq.agent(groq::GPT_4)
.preamble("You are comedian AI with a mission to make people laugh.")
.temperature(0.0)
.build();Sourcepub fn extractor<T: JsonSchema + for<'a> Deserialize<'a> + Serialize + Send + Sync>(
&self,
model: &str,
) -> ExtractorBuilder<T, CompletionModel>
pub fn extractor<T: JsonSchema + for<'a> Deserialize<'a> + Serialize + Send + Sync>( &self, model: &str, ) -> ExtractorBuilder<T, CompletionModel>
Create an extractor builder with the given completion model.