pub enum SubProvider {
HFInference,
Together,
SambaNova,
Fireworks,
Hyperbolic,
Nebius,
Novita,
Custom(String),
}Variants
Implementations
Sourceimpl SubProvider
impl SubProvider
Sourcepub fn completion_endpoint(&self, _model: &str) -> String
pub fn completion_endpoint(&self, _model: &str) -> String
Get the chat completion endpoint for the SubProvider Required because Huggingface Inference requires the model in the url and in the request body.
Sourcepub fn transcription_endpoint(
&self,
model: &str,
) -> Result<String, TranscriptionError>
pub fn transcription_endpoint( &self, model: &str, ) -> Result<String, TranscriptionError>
Get the transcription endpoint for the SubProvider Required because Huggingface Inference requires the model in the url and in the request body.
Sourcepub fn image_generation_endpoint(
&self,
model: &str,
) -> Result<String, ImageGenerationError>
pub fn image_generation_endpoint( &self, model: &str, ) -> Result<String, ImageGenerationError>
Get the image generation endpoint for the SubProvider Required because Huggingface Inference requires the model in the url and in the request body.
pub fn model_identifier(&self, model: &str) -> String