pub struct MiniMaxBuilder;Trait Implementations
Sourceimpl Clone for MiniMaxBuilder
impl Clone for MiniMaxBuilder
Sourcefn clone(&self) -> MiniMaxBuilder
fn clone(&self) -> MiniMaxBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MiniMaxBuilder
impl Debug for MiniMaxBuilder
Sourceimpl Default for MiniMaxBuilder
impl Default for MiniMaxBuilder
Sourcefn default() -> MiniMaxBuilder
fn default() -> MiniMaxBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for MiniMaxBuilder
impl ProviderBuilder for MiniMaxBuilder
const BASE_URL: &'static str = GLOBAL_API_BASE_URL
type Extension<H> = MiniMaxExt where H: HttpClientExt
type ApiKey = BearerAuth
Sourcefn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersimpl Copy for MiniMaxBuilder