pub struct ResponsesWebSocketSessionBuilder<T = Client> { /* private fields */ }Available on non-
target_family=wasm only.Expand description
A builder for an OpenAI Responses WebSocket session.
The default builder applies a 30 second connection timeout and leaves the per-event timeout disabled.
Implementations
Sourceimpl<T> ResponsesWebSocketSessionBuilder<T>
impl<T> ResponsesWebSocketSessionBuilder<T>
Sourcepub fn connect_timeout(self, timeout: Duration) -> Self
pub fn connect_timeout(self, timeout: Duration) -> Self
Sets the timeout for establishing the websocket connection.
Sourcepub fn without_connect_timeout(self) -> Self
pub fn without_connect_timeout(self) -> Self
Disables the websocket connection timeout.
Sourcepub fn event_timeout(self, timeout: Duration) -> Self
pub fn event_timeout(self, timeout: Duration) -> Self
Sets the timeout for waiting on the next websocket event.
Sourcepub fn without_event_timeout(self) -> Self
pub fn without_event_timeout(self) -> Self
Disables the websocket event timeout.
Sourceimpl<T> ResponsesWebSocketSessionBuilder<T>
impl<T> ResponsesWebSocketSessionBuilder<T>
Sourcepub async fn connect(
self,
) -> Result<ResponsesWebSocketSession<T>, CompletionError>
pub async fn connect( self, ) -> Result<ResponsesWebSocketSession<T>, CompletionError>
Opens the websocket session using the configured builder options.