pub enum ProviderSortStrategy {
Price,
Throughput,
Latency,
}Expand description
Simple sorting strategy for providers.
Determines how providers should be prioritized when multiple are available.
If you set sort, default load balancing is disabled and providers are tried
deterministically in the resulting order.
Variants
Price
Sort by price (cheapest first)
Throughput
Sort by throughput (higher tokens/sec first)
Latency
Sort by latency (lower latency first)