pub struct ZAiBuilder;Trait Implementations
Sourceimpl Clone for ZAiBuilder
impl Clone for ZAiBuilder
Sourcefn clone(&self) -> ZAiBuilder
fn clone(&self) -> ZAiBuilder
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ZAiBuilder
impl Debug for ZAiBuilder
Sourceimpl Default for ZAiBuilder
impl Default for ZAiBuilder
Sourcefn default() -> ZAiBuilder
fn default() -> ZAiBuilder
Returns the “default value” for a type. Read more
Sourceimpl ProviderBuilder for ZAiBuilder
impl ProviderBuilder for ZAiBuilder
const BASE_URL: &'static str = GENERAL_API_BASE_URL
type Extension<H> = ZAiExt where H: HttpClientExt
type ApiKey = BearerAuth
Sourcefn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
fn build<H>(
_builder: &ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<Self::Extension<H>>where
H: HttpClientExt,
Build the provider extension from the client builder configuration.
Sourcefn finish<H>(
&self,
builder: ClientBuilder<Self, Self::ApiKey, H>,
) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
fn finish<H>( &self, builder: ClientBuilder<Self, Self::ApiKey, H>, ) -> Result<ClientBuilder<Self, Self::ApiKey, H>>
This method can be used to customize the fields of
builder before it is used to create
a client. For example, adding default headersimpl Copy for ZAiBuilder