pub async fn stream_to_stdout<M: StreamingCompletionModel>(
agent: Agent<M>,
stream: &mut StreamingResult,
) -> Result<(), Error>Expand description
helper function to stream a completion request to stdout
pub async fn stream_to_stdout<M: StreamingCompletionModel>(
agent: Agent<M>,
stream: &mut StreamingResult,
) -> Result<(), Error>helper function to stream a completion request to stdout