pub struct Interest(/* private fields */);Expand description
Indicates a Subscriber’s interest in a particular callsite.
Subscribers return an Interest from their register_callsite methods
in order to determine whether that span should be enabled or disabled.
Implementations
Sourceimpl Interest
impl Interest
Sourcepub fn never() -> Interest
pub fn never() -> Interest
Returns an Interest indicating that the subscriber is never interested
in being notified about a callsite.
If all active subscribers are never() interested in a callsite, it will
be completely disabled unless a new subscriber becomes active.
Sourcepub fn sometimes() -> Interest
pub fn sometimes() -> Interest
Returns an Interest indicating the subscriber is sometimes interested
in being notified about a callsite.
If all active subscribers are sometimes or never interested in a
callsite, the currently active subscriber will be asked to filter that
callsite every time it creates a span. This will be the case until a new
subscriber expresses that it is always interested in the callsite.
Sourcepub fn always() -> Interest
pub fn always() -> Interest
Returns an Interest indicating the subscriber is always interested in
being notified about a callsite.
If any subscriber expresses that it is always() interested in a given
callsite, then the callsite will always be enabled.
Sourcepub fn is_never(&self) -> bool
pub fn is_never(&self) -> bool
Returns true if the subscriber is never interested in being notified
about this callsite.
Sourcepub fn is_sometimes(&self) -> bool
pub fn is_sometimes(&self) -> bool
Returns true if the subscriber is sometimes interested in being notified
about this callsite.