NoSubscriber

Struct NoSubscriber 

pub struct NoSubscriber(/* private fields */);
A no-op Subscriber.

NoSubscriber implements the Subscriber trait by never being enabled, never being interested in any callsite, and dropping all spans and events.

Implementations

Source

impl NoSubscriber

pub const fn new() -> NoSubscriber

Returns a new NoSubscriber.