rig

Module tool

Module defining tool related structs and traits.

The Tool trait defines a simple interface for creating tools that can be used by Agents.

The ToolEmbedding trait extends the Tool trait to allow for tools that can be stored in a vector store and RAGged.

The ToolSet struct is a collection of tools that can be used by an Agent and optionally RAGged.

Structs

Enums

Traits

  • Trait that represents a simple LLM tool
  • Wrapper trait to allow for dynamic dispatch of simple tools
  • Trait that represents an LLM tool that can be stored in a vector store and RAGged
  • Wrapper trait to allow for dynamic dispatch of raggable tools