#[non_exhaustive]pub struct Agent<M, P = ()>where
M: CompletionModel,
P: PromptHook<M>,{Show 16 fields
pub name: Option<String>,
pub description: Option<String>,
pub model: Arc<M>,
pub preamble: Option<String>,
pub static_context: Vec<Document>,
pub temperature: Option<f64>,
pub max_tokens: Option<u64>,
pub additional_params: Option<Value>,
pub tool_server_handle: ToolServerHandle,
pub dynamic_context: Arc<Vec<(usize, Arc<dyn VectorStoreIndexDyn + Send + Sync>)>>,
pub tool_choice: Option<ToolChoice>,
pub default_max_turns: Option<usize>,
pub hook: Option<P>,
pub output_schema: Option<Schema>,
pub memory: Option<Arc<dyn ConversationMemory>>,
pub default_conversation_id: Option<String>,
}Expand description
Struct representing an LLM agent. An agent is an LLM model combined with a preamble (i.e.: system prompt) and a static set of context documents and tools. All context documents and tools are always provided to the agent when prompted.
The optional type parameter P represents a default hook that will be used for all
prompt requests unless overridden via .with_hook() on the request.
Example
use rig_core::{
client::{CompletionClient, ProviderClient},
completion::Prompt,
providers::openai,
};
let openai = openai::Client::from_env()?;
let comedian_agent = openai
.agent(openai::GPT_5_2)
.preamble("You are a comedian here to entertain the user using humour and jokes.")
.temperature(0.9)
.build();
let response = comedian_agent.prompt("Entertain me!").await?;Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>Name of the agent used for logging and debugging
description: Option<String>Agent description. Primarily useful when using sub-agents as part of an agent workflow and converting agents to other formats.
model: Arc<M>Completion model (e.g.: OpenAI’s gpt-3.5-turbo-1106, Cohere’s command-r)
preamble: Option<String>System prompt
static_context: Vec<Document>Context documents always available to the agent
temperature: Option<f64>Temperature of the model
max_tokens: Option<u64>Maximum number of tokens for the completion
additional_params: Option<Value>Additional parameters to be passed to the model
tool_server_handle: ToolServerHandledynamic_context: Arc<Vec<(usize, Arc<dyn VectorStoreIndexDyn + Send + Sync>)>>List of vector store, with the sample number
tool_choice: Option<ToolChoice>Whether or not the underlying LLM should be forced to use a tool before providing a response.
default_max_turns: Option<usize>Default maximum depth for recursive agent calls
hook: Option<P>Default hook for this agent, used when no per-request hook is provided
output_schema: Option<Schema>Optional JSON Schema for structured output. When set, providers that support native structured outputs will constrain the model’s response to match this schema.
memory: Option<Arc<dyn ConversationMemory>>Optional conversation memory backend that loads/saves history per conversation id.
default_conversation_id: Option<String>Optional default conversation id used when none is set per-request.