Message

Enum Message 

pub enum Message {
    System {
        content: String,
    },
    User {
        content: OneOrMany<UserContent>,
    },
    Assistant {
        id: Option<String>,
        content: OneOrMany<AssistantContent>,
    },
}
A message represents a run of input (user) and output (assistant). Each message type (based on it’s role) can contain a atleast one bit of content such as text, images, audio, documents, or tool related information. While each message type can contain multiple content, most often, you’ll only see one content type per message (an image w/ a description, etc).

Each provider is responsible with converting the generic message into it’s provider specific type using From or TryFrom traits. Since not every provider supports every feature, the conversion can be lossy (providing an image might be discarded for a non-image supporting provider) though the message being converted back and forth should always be the same.

Variants



System

System message containing instruction text.

Fields

content: String


User

User message containing one or more content types defined by UserContent.

Fields



Assistant

Assistant message containing one or more content types defined by AssistantContent.

Implementations

Source

impl Message

pub fn system(text: impl Into<String>) -> Message

Helper constructor to make creating system messages easier.

pub fn user(text: impl Into<String>) -> Message

Helper constructor to make creating user messages easier.

pub fn assistant(text: impl Into<String>) -> Message

Helper constructor to make creating assistant messages easier.

pub fn assistant_with_id(id: String, text: impl Into<String>) -> Message

Helper constructor to make creating assistant messages easier.

pub fn tool_result(id: impl Into<String>, content: impl Into<String>) -> Message

Helper constructor to make creating tool result messages easier.

pub fn tool_result_with_call_id( id: impl Into<String>, call_id: Option<String>, content: impl Into<String>, ) -> Message