An SSE implementation that leverages crate::http_client::HttpClientExt to allow streaming with automatic retry handling for any implementor of HttpClientExt.
Primarily intended for internal usage. However if you also wish to implement generic HTTP streaming for your custom completion model, you may find this helpful.
Structs
- Generic
Event Source - A generic SSE event source that works with any
HttpClientExtimplementation.
Enums
- Event
- Events created by the
GenericEventSource