pub struct ResponsesWebSocketSessionBuilder<H = Client> { /* private fields */ }Available on non-
target_family=wasm and crate feature websocket only.Expand description
A builder for an OpenAI Responses WebSocket session.
The default builder applies a 30 second connection timeout and leaves the per-event timeout disabled.
Implementations
Sourceimpl<H> ResponsesWebSocketSessionBuilder<H>
impl<H> ResponsesWebSocketSessionBuilder<H>
Sourcepub fn connect_timeout(self, timeout: Duration) -> Self
pub fn connect_timeout(self, timeout: Duration) -> Self
Sets the timeout for establishing the websocket connection.
Sourcepub fn without_connect_timeout(self) -> Self
pub fn without_connect_timeout(self) -> Self
Disables the websocket connection timeout.
Sourcepub fn event_timeout(self, timeout: Duration) -> Self
pub fn event_timeout(self, timeout: Duration) -> Self
Sets the timeout for waiting on the next websocket event.
Sourcepub fn without_event_timeout(self) -> Self
pub fn without_event_timeout(self) -> Self
Disables the websocket event timeout.
Sourceimpl<H> ResponsesWebSocketSessionBuilder<H>
impl<H> ResponsesWebSocketSessionBuilder<H>
Sourcepub async fn connect(
self,
) -> Result<ResponsesWebSocketSession<H>, CompletionError>
pub async fn connect( self, ) -> Result<ResponsesWebSocketSession<H>, CompletionError>
Opens the websocket session using the configured builder options.