pub struct OneOrMany<T> { /* private fields */ }Expand description
Struct containing either a single item or a list of items of type T.
If a single item is present, first will contain it and rest will be empty.
If multiple items are present, first will contain the first item and rest will contain the rest.
IMPORTANT: this struct cannot be created with an empty vector.
OneOrMany objects can only be created using OneOrMany::from() or OneOrMany::try_from().
Implementations
Sourceimpl<T> OneOrMany<T>where
T: Clone,
impl<T> OneOrMany<T>where
T: Clone,
Sourcepub fn push(&mut self, item: T)
pub fn push(&mut self, item: T)
After OneOrMany<T> is created, add an item of type T to the rest.
Sourcepub fn insert(&mut self, index: usize, item: T)
pub fn insert(&mut self, index: usize, item: T)
After OneOrMany<T> is created, insert an item of type T at an index.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
If OneOrMany<T> is empty. This will always be false because you cannot create an empty OneOrMany<T>.
This method is required when the method len exists.
Sourcepub fn many<I>(items: I) -> Result<OneOrMany<T>, EmptyListError>where
I: IntoIterator<Item = T>,
pub fn many<I>(items: I) -> Result<OneOrMany<T>, EmptyListError>where
I: IntoIterator<Item = T>,
Create a OneOrMany object with a vector of items of any type.
Sourcepub fn merge<I>(one_or_many_items: I) -> Result<OneOrMany<T>, EmptyListError>where
I: IntoIterator<Item = OneOrMany<T>>,
pub fn merge<I>(one_or_many_items: I) -> Result<OneOrMany<T>, EmptyListError>where
I: IntoIterator<Item = OneOrMany<T>>,
Merge a list of OneOrMany items into a single OneOrMany item.
pub fn iter(&self) -> Iter<'_, T> ⓘ
pub fn iter_mut(&mut self) -> IterMut<'_, T> ⓘ