ToolSet

Struct ToolSet 

pub struct ToolSet { /* private fields */ }
A struct that holds a set of tools

Implementations

Source

impl ToolSet

pub fn from_tools(tools: Vec<impl ToolDyn + 'static>) -> ToolSet

Create a new ToolSet from a list of tools

pub fn from_tools_boxed(tools: Vec<Box<dyn ToolDyn>>) -> ToolSet

pub fn builder() -> ToolSetBuilder

Create a toolset builder

pub fn contains(&self, toolname: &str) -> bool

Check if the toolset contains a tool with the given name

pub fn add_tool(&mut self, tool: impl ToolDyn + 'static)

Add a tool to the toolset

pub fn add_tool_boxed(&mut self, tool: Box<dyn ToolDyn>)

Adds a boxed tool to the toolset. Useful for situations when dynamic dispatch is required.

pub fn delete_tool(&mut self, tool_name: &str)

pub fn add_tools(&mut self, toolset: ToolSet)

Merge another toolset into this one

pub async fn get_tool_definitions( &self, ) -> Result<Vec<ToolDefinition>, ToolSetError>

pub async fn call( &self, toolname: &str, args: String, ) -> Result<String, ToolSetError>

Call a tool with the given name and arguments

pub async fn documents(&self) -> Result<Vec<Document>, ToolSetError>

Get the documents of all the tools in the toolset

pub fn schemas(&self) -> Result<Vec<ToolSchema>, EmbedError>

Convert tools in self to objects of type ToolSchema. This is necessary because when adding tools to the EmbeddingBuilder because all documents added to the builder must all be of the same type.