pub struct ToolSet { /* private fields */ }Expand description
A struct that holds a set of tools
Implementations
Sourceimpl ToolSet
impl ToolSet
Sourcepub fn from_tools(tools: Vec<impl ToolDyn + 'static>) -> ToolSet
pub fn from_tools(tools: Vec<impl ToolDyn + 'static>) -> ToolSet
Create a new ToolSet from a list of tools
pub fn from_tools_boxed(tools: Vec<Box<dyn ToolDyn>>) -> ToolSet
Sourcepub fn builder() -> ToolSetBuilder
pub fn builder() -> ToolSetBuilder
Create a toolset builder
Sourcepub fn contains(&self, toolname: &str) -> bool
pub fn contains(&self, toolname: &str) -> bool
Check if the toolset contains a tool with the given name
Sourcepub fn add_tool_boxed(&mut self, tool: Box<dyn ToolDyn>)
pub fn add_tool_boxed(&mut self, tool: Box<dyn ToolDyn>)
Adds a boxed tool to the toolset. Useful for situations when dynamic dispatch is required.
pub fn delete_tool(&mut self, tool_name: &str)
pub async fn get_tool_definitions( &self, ) -> Result<Vec<ToolDefinition>, ToolSetError>
Sourcepub async fn call(
&self,
toolname: &str,
args: String,
) -> Result<String, ToolSetError>
pub async fn call( &self, toolname: &str, args: String, ) -> Result<String, ToolSetError>
Call a tool with the given name and arguments
Sourcepub async fn documents(&self) -> Result<Vec<Document>, ToolSetError>
pub async fn documents(&self) -> Result<Vec<Document>, ToolSetError>
Get the documents of all the tools in the toolset
Sourcepub fn schemas(&self) -> Result<Vec<ToolSchema>, EmbedError>
pub fn schemas(&self) -> Result<Vec<ToolSchema>, EmbedError>
Convert tools in self to objects of type ToolSchema. This is necessary because when adding tools to the EmbeddingBuilder because all documents added to the builder must all be of the same type.